Iterator utilities and extensions for working with targets and results.
This module provides idiomatic Rust iterator patterns for processing collections of targets and results.
Structs
- Result
Summary - Summary statistics for wait results
Traits
- Target
Iter Ext - Extension trait for working with iterators of targets
- Target
Result Iter Ext - Extension trait for working with iterators of target results
- Target
Result Slice Ext - Extension trait for slices/Vecs of
TargetResultto provide summary functionality